##
##  gomplate.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gomplate
Summary:      Go Template Tool
URL:          https://github.com/hairyhenderson/gomplate
Vendor:       Dave Henderson
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Text
License:      MIT
Version:      4.3.0
Release:      20241217

#   list of sources
Source0:      https://github.com/hairyhenderson/gomplate/archive/v%{version}.tar.gz
Source1:      gomplate-generate.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This is a Go Template tool.

%track
    prog gomplate = {
        version   = %{version}
        url       = https://github.com/hairyhenderson/gomplate/releases
        regex     = v(__VER__)\.tar\.gz
    }

%prep
    %setup -q -T -c

%build
    #   build program
    export GOPATH=`pwd`
    %{l_shtool} mkdir -f -p -m 755 -p $GOPATH/src/xxx
    (   cd src/xxx
        %{l_gzip} -c -d %{SOURCE0} | %{l_tar} xf -
    ) || exit $?
    mkdir -p src/github.com/hairyhenderson
    mv src/xxx/gomplate-* src/github.com/hairyhenderson/gomplate
    cd src/github.com/hairyhenderson/gomplate
    go build \
        -v \
        -ldflags "-X `go list ./version`.GitCommit=000000 -X `go list ./version`.Version=%{version}" \
        -o gomplate \
        ./cmd/gomplate

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/hairyhenderson/gomplate/gomplate \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE gomplate-generate.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/bin/gomplate-generate

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

